From: tip-bot for Torben Hohn <torbenh@gmx.de>
To: linux-tip-commits@vger.kernel.org
Cc: linux-kernel@vger.kernel.org, hpa@zytor.com, mingo@redhat.com,
jesper.nilsson@axis.com, peterz@infradead.org, torbenh@gmx.de,
starvik@axis.com, tglx@linutronix.de
Subject: [tip:timers/core] cris: arch-v32: Switch do_timer() to xtime_update()
Date: Mon, 31 Jan 2011 14:07:53 GMT [thread overview]
Message-ID: <tip-36cb07bb8118cb14211ef25c58026f005877c47d@git.kernel.org> (raw)
In-Reply-To: <20110127145941.23248.92547.stgit@localhost>
Commit-ID: 36cb07bb8118cb14211ef25c58026f005877c47d
Gitweb: http://git.kernel.org/tip/36cb07bb8118cb14211ef25c58026f005877c47d
Author: Torben Hohn <torbenh@gmx.de>
AuthorDate: Thu, 27 Jan 2011 15:59:41 +0100
Committer: Thomas Gleixner <tglx@linutronix.de>
CommitDate: Mon, 31 Jan 2011 14:55:44 +0100
cris: arch-v32: Switch do_timer() to xtime_update()
xtime_update() takes the xtime_lock itself.
Signed-off-by: Torben Hohn <torbenh@gmx.de>
Cc: hch@infradead.org
Cc: Jesper Nilsson <jesper.nilsson@axis.com>
Cc: Peter Zijlstra <peterz@infradead.org>
Cc: johnstul@us.ibm.com
Cc: Mikael Starvik <starvik@axis.com>
Cc: yong.zhang0@gmail.com
LKML-Reference: <20110127145941.23248.92547.stgit@localhost>
Signed-off-by: Thomas Gleixner <tglx@linutronix.de>
---
arch/cris/arch-v32/kernel/time.c | 6 ++----
1 files changed, 2 insertions(+), 4 deletions(-)
diff --git a/arch/cris/arch-v32/kernel/time.c b/arch/cris/arch-v32/kernel/time.c
index a545211..bb978ed 100644
--- a/arch/cris/arch-v32/kernel/time.c
+++ b/arch/cris/arch-v32/kernel/time.c
@@ -183,7 +183,7 @@ void handle_watchdog_bite(struct pt_regs *regs)
/*
* timer_interrupt() needs to keep up the real-time clock,
* as well as call the "do_timer()" routine every clocktick.
*/
extern void cris_do_profile(struct pt_regs *regs);
@@ -216,9 +216,7 @@ static inline irqreturn_t timer_interrupt(int irq, void *dev_id)
return IRQ_HANDLED;
/* Call the real timer interrupt handler */
- write_seqlock(&xtime_lock);
- do_timer(1);
- write_sequnlock(&xtime_lock);
+ xtime_update(1);
return IRQ_HANDLED;
}
next prev parent reply other threads:[~2011-01-31 14:08 UTC|newest]
Thread overview: 51+ messages / expand[flat|nested] mbox.gz Atom feed top
2011-01-27 14:58 [PATCH v2 00/20] localize xtime_lock usage to kernel/time/ Torben Hohn
2011-01-27 14:58 ` [PATCH v2 01/20] move do_timer() from kernel/timer.c into kernel/time/timekeeping.c Torben Hohn
2011-01-31 14:03 ` [tip:timers/core] time: Move do_timer() to kernel/time/timekeeping.c tip-bot for Torben Hohn
2011-01-27 14:59 ` [PATCH v2 02/20] move get_jiffies_64 to kernel/time/jiffies.c Torben Hohn
2011-01-31 11:36 ` Thomas Gleixner
2011-01-31 14:04 ` [tip:timers/core] time: Move " tip-bot for Torben Hohn
2011-01-27 14:59 ` [PATCH v2 03/20] provide get_xtime_and_monotonic_offset() and use it in hrtimer.c Torben Hohn
2011-01-31 11:38 ` Thomas Gleixner
2011-01-31 14:04 ` [tip:timers/core] time: Provide get_xtime_and_monotonic_offset() tip-bot for Torben Hohn
2011-02-01 9:21 ` [tip:timers/core] time: Fix legacy arch fallout tip-bot for Thomas Gleixner
2011-01-27 14:59 ` [PATCH v2 04/20] provide xtime_update() which does not require the caller to hold xtime_lock Torben Hohn
2011-01-31 14:05 ` [tip:timers/core] time: Provide xtime_update() tip-bot for Torben Hohn
2011-01-27 14:59 ` [PATCH v2 05/20] alpha: change do_timer() to xtime_update() Torben Hohn
2011-01-31 10:23 ` Thomas Gleixner
2011-01-31 10:32 ` Thomas Gleixner
2011-01-31 14:05 ` [tip:timers/core] alpha: Change " tip-bot for Torben Hohn
2011-01-27 14:59 ` [PATCH v2 06/20] arm: switch from " Torben Hohn
2011-01-31 14:06 ` [tip:timers/core] arm: Switch " tip-bot for Torben Hohn
2011-01-27 14:59 ` [PATCH v2 07/20] arm/mach-clps711x: switch " Torben Hohn
2011-01-31 14:06 ` [tip:timers/core] arm/mach-clps711x: Switch " tip-bot for Torben Hohn
2011-01-27 14:59 ` [PATCH v2 08/20] blackfin: switch from " Torben Hohn
2011-01-27 19:42 ` Mike Frysinger
2011-01-31 14:07 ` [tip:timers/core] blackfin: Switch " tip-bot for Torben Hohn
2011-01-27 14:59 ` [PATCH v2 09/20] cris/arch-v10: switch " Torben Hohn
2011-01-31 14:07 ` [tip:timers/core] cris: arch-v10: Switch " tip-bot for Torben Hohn
2011-01-27 14:59 ` [PATCH v2 10/20] cris/arch-v32: switch " Torben Hohn
2011-01-31 14:07 ` tip-bot for Torben Hohn [this message]
2011-01-27 14:59 ` [PATCH v2 11/20] frv: " Torben Hohn
2011-01-31 14:08 ` [tip:timers/core] frv: Switch " tip-bot for Torben Hohn
2011-01-27 14:59 ` [PATCH v2 12/20] h8300: switch " Torben Hohn
2011-01-31 14:08 ` [tip:timers/core] h8300: Switch " tip-bot for Torben Hohn
2011-01-27 14:59 ` [PATCH v2 13/20] ia64: switch " Torben Hohn
2011-01-31 14:09 ` [tip:timers/core] ia64: Switch " tip-bot for Torben Hohn
2011-01-27 15:00 ` [PATCH v2 14/20] m32r: switch from " Torben Hohn
2011-01-31 14:09 ` [tip:timers/core] m32r: Switch " tip-bot for Torben Hohn
2011-01-27 15:00 ` [PATCH v2 15/20] m68k: switch " Torben Hohn
2011-01-31 14:09 ` [tip:timers/core] m68k: Switch " tip-bot for Torben Hohn
2011-02-03 23:07 ` Greg Ungerer
2011-01-27 15:00 ` [PATCH v2 16/20] mn10300: switch do_timer() to xtimer_update() Torben Hohn
2011-01-31 13:47 ` Thomas Gleixner
2011-03-18 16:35 ` David Howells
2011-02-09 15:18 ` [tip:timers/core] mn10300: Switch " tip-bot for Torben Hohn
2011-01-27 15:00 ` [PATCH v2 17/20] parisc: switch do_timer() to xtime_update() Torben Hohn
2011-01-31 14:10 ` [tip:timers/core] parisc: Switch " tip-bot for Torben Hohn
2011-01-27 15:00 ` [PATCH v2 18/20] sparc: switch " Torben Hohn
2011-01-31 14:10 ` [tip:timers/core] sparc: Switch " tip-bot for Torben Hohn
2011-01-27 15:00 ` [PATCH v2 19/20] xtensa: switch " Torben Hohn
2011-01-31 14:11 ` [tip:timers/core] xtensa: Switch " tip-bot for Torben Hohn
2011-01-27 15:00 ` [PATCH v2 20/20] make do_timer() and xtime_lock private to the timer code Torben Hohn
2011-01-31 14:11 ` [tip:timers/core] time: Make do_timer() and xtime_lock local to kernel/time/ tip-bot for Torben Hohn
2011-01-31 18:21 ` tip-bot for Torben Hohn
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=tip-36cb07bb8118cb14211ef25c58026f005877c47d@git.kernel.org \
--to=torbenh@gmx.de \
--cc=hpa@zytor.com \
--cc=jesper.nilsson@axis.com \
--cc=linux-kernel@vger.kernel.org \
--cc=linux-tip-commits@vger.kernel.org \
--cc=mingo@redhat.com \
--cc=peterz@infradead.org \
--cc=starvik@axis.com \
--cc=tglx@linutronix.de \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -183,7 +183,7 @@ void handle_watchdog_bite(struct pt_regs *regs)
/*
* timer_interrupt() needs to keep up the real-time clock,
- * as well as call the "do_timer()" routine every clocktick.
+ * as well as call the "xtime_update()" routine every clocktick.
*/
extern void cris_do_profile(struct pt_regs *regs);
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.